==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/veo35.cpp <==
/* @lastChanged: "1999-04-21  19:16"
 * @filename:    veo35.cpp
 * @purpose:     "DCOMx_Functions"
 * @release:     7.2.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/
//#include "ggg00.h"
#include "gsp00.h"
#include "geo00k.h"

#if !defined(_WIN32)
#include "gco00.h" /* nocheck */
#endif
#include "heo35.h"
#include "heo36.h"
#include "heo38.h"
#include "heo47.h"
#include "heo60.h"
#include "gen500.h"
#if defined(_WIN32)
#include "hos39.h" /* nocheck */
#endif
/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE	inline
#endif

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/

/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/

/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/

/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

externC void vdcom_iid_ilivecachespec ( tsp00_C16*      pIId )
{
  ROUTINE_DBG_MEO00 ("vdcom_iid_ilivecachespec");

  eo38IIdILiveCacheSpec ( pIId );

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_get_classobject ( bool            fDebug,
                                        void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_co_get_classobject");
  *pOk = true;
#if defined (_WIN32)
  if ( fDebug )
  {
    os39CoGetClassobject ( (tsp_dcom_co_create_instance_parms*) pInstance );
  }
  else 
#endif
    eo38CoGetClassObject((tsp_dcom_co_create_instance_parms*) pInstance );
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_create_instance ( void            *pInstance,
                                        bool            *pOk,
                                        tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_co_create_instance");
  eo38CoCreateInstance ((tsp_dcom_co_create_instance_parms*) pInstance );
  *pOk = true;
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_paraminfo ( bool            fDebug,
                               void            *pParamInfo,
                               bool            *pOk,
                               tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_paraminfo");
  
  
  *pOk = true;
#if defined (_WIN32)
  if ( !fDebug ) {
    eo36ParamInfo ( (tsp_dcom_paraminfo_parms*)pParamInfo );
  }
  else {
    os39VDcomParamInfo( (tsp_dcom_paraminfo_parms*)pParamInfo );
  }
#else
  eo36ParamInfo ( (tsp_dcom_paraminfo_parms*)pParamInfo );
#endif
  return;
}

/*---------------------------------------------------------------------------*/


externC void vdcom_create_instance ( bool            fDebug,
                                     void            *pInstance,
                                     bool            *pOk,
                                     tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_create_instance");

  *pOk = true;   // sql35_vdcom_create_instance einfuehren !!!!!

  if ( fDebug )
     eo38VDcomCreateInstance ( (tsp_dcom_co_create_instance_parms*)pInstance );
  else
     eo38VDcomCreateInstance ( (tsp_dcom_co_create_instance_parms*)pInstance );

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_instance ( void            *pParamInfo,
                                      bool            *pOk,
                                      tsp00_ErrText   *pErrtext )
{
  ROUTINE_DBG_MEO00 ("vdcom_release_instance");

  eo38ReleaseInstance ( (tsp_dcom_release_instance_parms *) pParamInfo );
  *pOk = true;
  /*
  *pOk = sql35_VDCOMiRequest ( REQ_DCOM_RELEASE_INSTANCE_EO00K, pParamInfo, *pErrtext );
  */
  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_all ( )
{
  ROUTINE_DBG_MEO00 ("vdcom_release_all");

  //tsp00_ErrText   Errtext;
  //bool            Ok;

  eo38VDcomReleaseAll(NULL);
 
  //Ok = sql35_VDCOMiRequest ( REQ_DCOM_RELASE_ALL_EO00K, NULL, Errtext );

  return;
}

/*---------------------------------------------------------------------------*

externC void vdcom_dispatch ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_dispatch");

  eo38VDcomDispatch ( (tsp_dcom_dispatch_parms*) pParamInfo );

  return;
}
not needed    FF 12-Jan-2000 */
/*---------------------------------------------------------------------------*/

externC void vdcom_dbproc ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_dbproc");

  eo38VDcomDBProc ( (tsp_dcom_dispatch_parms*) pParamInfo );

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_trans_end ( void *pParamInfo )
{
  ROUTINE_DBG_MEO00 ("vdcom_trans_end");

  eo38VDcomTransEnd ( (tsp_dcom_dispatch_parms*) pParamInfo );

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_get_dispaddr ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_get_dispaddr");

  eo38VDcomGetDispAddr ( (tsp_dcom_co_create_instance_parms*) pInstance );

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_init_sink ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_init_sink");

  eo38VDcomInitSink ( (tsp_dcom_init_sink_parms*) pInstance );

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_invalidate ( void *pInstance )
{
  ROUTINE_DBG_MEO00 ("vdcom_invalidate");

  eo38VDcomInvalidate ( (tsp_dcom_co_create_instance_parms*) pInstance );

  return;
}

/*---------------------------------------------------------------------------*/

/*--* +++ Change Request 1000139 T.A. 14.10.1998 +++ *------------------------*/

externC void vdcom_monitor_open ( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MSP00 ("vdcom_monitor_open");

  os38kVDcomMonOpen (parms);

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_monitor_next ( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MSP00 ("vdcom_monitor_next");

  os38kVDcomMonNext (parms);

  return;
}

/*---------------------------------------------------------------------------*/

externC void vdcom_monitor_close ( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MSP00 ("vdcom_monitor_close");

  os38kVDcomMonClose (parms);

  return;
}
/*--* +++ End Change Request ------------------------------------------------*/

/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/veo35.cpp <==
/* @lastChanged: "1999-04-21  19:16"
 * @filename:    veo35.cpp
 * @purpose:     "DCOMx_Functions"
 * @release:     7.2.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "heo35.h"
#include "heo38.h"
#include "heo36.h"
#include "geo60.h"

/*===========================================================================*
*  GLOBAL FUNCTIONS (CODE)                                                  *
*===========================================================================*/

externC void vdcom_iid_ilivecachespec ( tsp00_C16* pIId )
{
  ROUTINE_DBG_MEO60 ("vdcom_iid_ilivecachespec");  
  eo38IIdILiveCacheSpec ( pIId );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_co_get_classobject (void *pInstance )
{
  ROUTINE_DBG_MEO60 ("vdcom_co_get_classobject");
  eo38CoGetClassObject((tsp_dcom_co_create_instance_parms*) pInstance );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_paraminfo (void *pParamInfo )
{
  ROUTINE_DBG_MEO60 ("vdcom_paraminfo");
  eo36ParamInfo ( (tsp_dcom_paraminfo_parms*)pParamInfo );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_create_instance ( void *pInstance )
{
  ROUTINE_DBG_MEO60 ("vdcom_create_instance");
  eo38VDcomCreateInstance ( (tsp_dcom_co_create_instance_parms*)pInstance );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_instance ( void *pParamInfo )
{
  ROUTINE_DBG_MEO60 ("vdcom_release_instance");
  eo38ReleaseInstance ( (tsp_dcom_release_instance_parms *) pParamInfo );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_release_all ( )
{
  ROUTINE_DBG_MEO60 ("vdcom_release_all");
  eo38VDcomReleaseAll(NULL);
}

/*---------------------------------------------------------------------------*/

externC void vdcom_dbproc ( void *pParamInfo )
{
  ROUTINE_DBG_MEO60 ("vdcom_dbproc");
  eo38VDcomDBProc ( (tsp_dcom_dispatch_parms*) pParamInfo );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_trans_end ( void *pParamInfo )
{
  ROUTINE_DBG_MEO60 ("vdcom_trans_end");
  eo38VDcomTransEnd ( (tsp_dcom_dispatch_parms*) pParamInfo );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_get_dispaddr ( void *pInstance )
{
  ROUTINE_DBG_MEO60 ("vdcom_get_dispaddr");
  eo38VDcomGetDispAddr ( (tsp_dcom_co_create_instance_parms*) pInstance );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_init_sink ( void *pInstance )
{
  ROUTINE_DBG_MEO60 ("vdcom_init_sink");
  eo38VDcomInitSink ( (tsp_dcom_init_sink_parms*) pInstance );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_invalidate ( void *pInstance )
{
  ROUTINE_DBG_MEO60 ("vdcom_invalidate");
  eo38VDcomInvalidate ( (tsp_dcom_co_create_instance_parms*) pInstance );
}

/*---------------------------------------------------------------------------*/

externC void vdcom_monitor_open ( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO60 ("vdcom_monitor_open");
  eo38VDcomMonOpen (parms);
}

/*---------------------------------------------------------------------------*/

externC void vdcom_monitor_next ( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO60 ("vdcom_monitor_next");
  eo38VDcomMonNext (parms);
}

/*---------------------------------------------------------------------------*/

externC void vdcom_monitor_close ( tsp_dcom_monitor_parms * parms )
{
  ROUTINE_DBG_MEO60 ("vdcom_monitor_close");
  eo38VDcomMonClose (parms);
}

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
